import EventEmitter from "eventemitter3";
import { type ServerErrors } from "./serverErrors.mts";
declare const ResponseErrors: {
    readonly PARSE_ERROR: -32700;
    readonly INVALID_REQUEST: -32600;
    readonly METHOD_NOT_FOUND: -32601;
    readonly INVALID_PARAMS: -32602;
    readonly INTERNAL_ERROR: -32603;
};
type ResponseErrorKeys = keyof typeof ResponseErrors;
type ResponseErrorValues = (typeof ResponseErrors)[ResponseErrorKeys] | ServerErrors;
export interface Request {
    jsonrpc: "2.0";
    method: string;
    params: any;
    id?: string | number | null;
}
interface Response {
    jsonrpc: "2.0";
    id?: string | number | null;
}
export interface ResponseSuccess extends Response {
    result: any;
}
export interface ResponseError extends Response {
    error: {
        code: ResponseErrorValues;
        message: string;
        data?: any;
    };
}
export type Responses = ResponseSuccess | ResponseError;
type PartialRequest = Omit<Request, "jsonrpc" | "">;
export declare class JsonRpcError extends Error {
    code: number | string;
    response: ResponseError | null;
    constructor(message?: string, options?: ErrorOptions & {
        code: number | string;
        response: ResponseError;
    });
}
export declare class JsonRpc extends EventEmitter {
    _requests: Map<number, Request>;
    _lastId: number;
    send(request: PartialRequest): Promise<ResponseSuccess>;
    send(request: PartialRequest[]): Promise<Responses[]>;
    notify(request: PartialRequest): void;
    notify(request: PartialRequest[]): void;
    _process(request: PartialRequest, resolve: Parameters<ConstructorParameters<typeof Promise<ResponseSuccess>>[0]>[0], reject: Parameters<ConstructorParameters<typeof Promise<ResponseError>>[0]>[1]): void;
    _processBatch(request: PartialRequest[], resolve: Parameters<ConstructorParameters<typeof Promise<Responses[]>>[0]>[0]): void;
}
export {};
//# sourceMappingURL=index.d.mts.map